==> react-formality-1.4.16.tgz: package/src/form.js <==
import React, { Component } from 'react'
import PropTypes from 'prop-types'

class Form extends Component {
	//	Setup a few defaults
	constructor(props) {
		super(props)

		this.state = {
			verbose: false,
			attribs: {
				onSubmit: this.handleOnSubmit.bind(this, props.onSubmit)
			}
		}

		this.debug = this.debug.bind(this)
	}

	getChildContext() {
		return {
			store: this.props.store,
			debug: this.props.debug
		}
	}

	debug(obj) {
		if (this.props.debug) {
			console.log('Formality form', obj) // eslint-disable-line no-console
		}
	}

	submit() {
		this.form.dispatchEvent(new Event('submit', { cancelable: true }))
	}

	// TODO: might be able to ease up on the validation calling on submit...
	// TODO: might also be able to debounce the change/blur and this one as a group... with a properly extracted validateForm function... probably needs to be memoised though... (so it's chosen by name)
	async handleOnSubmit(oldHandler, e) {
		e.preventDefault()

		// trigger all the field validations (and re-renders)
		const fieldValidationResults = await Promise.all(
			Object.keys(this.props.store.fieldRefs)
				.map(async (name) => {
					const fieldRefs = Array.isArray(this.props.store.fieldRefs[name]) ? this.props.store.fieldRefs[name] : [this.props.store.fieldRefs[name]]
					const validationResults = await Promise.all(fieldRefs.map(fieldRef => fieldRef.validate(false)))
					const validationResult = validationResults.reduce((acc, curr) => [...acc, ...(curr || [])], [])
					return {
						[name]: validationResult
					}
				})
		)

		const validationResults = fieldValidationResults.reduce((acc, curr) => ({ ...acc, ...curr }), {})
		const validationResult = Object.keys(validationResults).every(key => !validationResults[key])

		this.props.store.setValidations(validationResults)

		if (oldHandler) {
			oldHandler.apply(this, [e, this.props.store.values, validationResult, validationResults])
		}

		this.debug({ handleOnSubmit: {
			store: this.props.store,
			validationResult,
			validationResults,
			hasOldHandler: !!oldHandler
		} })
	}

	render() {
		const attribs = { ...this.props, ...this.state.attribs }

		delete attribs.debug
		delete attribs.store
		delete attribs.children

		return (
			<form
				{...attribs}
				ref={(el) => {
					this.form = el
				}}
			>
				{this.props.children}
			</form>
		)
	}
}

Form.childContextTypes = {
	store: PropTypes.object,
	debug: PropTypes.bool
}

Form.propTypes = {
	debug: PropTypes.bool,
	store: PropTypes.object.isRequired, // eslint-disable-line react/forbid-prop-types
	onSubmit: PropTypes.func,
	children: PropTypes.any, // eslint-disable-line react/forbid-prop-types
}

Form.defaultProps = {
	debug: undefined,
	onSubmit: undefined,
	children: undefined
}

export default Form

==> react-formality-1.4.18.tgz: package/src/form.js <==
import React, { Component } from 'react'
import PropTypes from 'prop-types'

class Form extends Component {
	//	Setup a few defaults
	constructor(props) {
		super(props)

		this.state = {
			verbose: false,
			attribs: {
				onSubmit: this.handleOnSubmit.bind(this, props.onSubmit)
			}
		}

		this.debug = this.debug.bind(this)
	}

	getChildContext() {
		return {
			store: this.props.store,
			debug: this.props.debug
		}
	}

	debug(obj) {
		if (this.props.debug) {
			console.log('Formality form', obj) // eslint-disable-line no-console
		}
	}

	submit() {
		this.form.dispatchEvent(new Event('submit', { cancelable: true }))
	}

	// TODO: might be able to ease up on the validation calling on submit...
	// TODO: might also be able to debounce the change/blur and this one as a group... with a properly extracted validateForm function... probably needs to be memoised though... (so it's chosen by name)
	async handleOnSubmit(oldHandler, e) {
		e.preventDefault()

		// trigger all the field validations (and re-renders)
		const fieldValidationResults = await Promise.all(
			Object.keys(this.props.store.fieldRefs)
				.map(async (name) => {
					const fieldRefs = Array.isArray(this.props.store.fieldRefs[name]) ? this.props.store.fieldRefs[name] : [this.props.store.fieldRefs[name]]
					const validationResults = await Promise.all(fieldRefs.map(fieldRef => fieldRef.validate(false)))
					const validationResult = validationResults.reduce((acc, curr) => [...acc, ...(curr || [])], [])
					return {
						[name]: validationResult.length ? validationResult : undefined
					}
				})
		)

		const validationResults = fieldValidationResults.reduce((acc, curr) => ({ ...acc, ...curr }), {})
		const validationResult = Object.keys(validationResults).every(key => !validationResults[key])

		this.props.store.setValidations(validationResults)

		if (oldHandler) {
			oldHandler.apply(this, [e, this.props.store.values, validationResult, validationResults])
		}

		this.debug({ handleOnSubmit: {
			store: this.props.store,
			validationResult,
			validationResults,
			hasOldHandler: !!oldHandler
		} })
	}

	render() {
		const attribs = { ...this.props, ...this.state.attribs }

		delete attribs.debug
		delete attribs.store
		delete attribs.children

		return (
			<form
				{...attribs}
				ref={(el) => {
					this.form = el
				}}
			>
				{this.props.children}
			</form>
		)
	}
}

Form.childContextTypes = {
	store: PropTypes.object,
	debug: PropTypes.bool
}

Form.propTypes = {
	debug: PropTypes.bool,
	store: PropTypes.object.isRequired, // eslint-disable-line react/forbid-prop-types
	onSubmit: PropTypes.func,
	children: PropTypes.any, // eslint-disable-line react/forbid-prop-types
}

Form.defaultProps = {
	debug: undefined,
	onSubmit: undefined,
	children: undefined
}

export default Form
